==> nextcloud-app-calendar-1.5.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/de.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Too many redirects. Aborting ..." : "Zu viele Umleitungen. Abbruch ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Der entfernte Server erlaubt keinen Zugriff auf den Kalender (HTTP {%s} error)",
    "Error connecting to remote server" : "Fehler bei der Verbindung zum entfernten Server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fehler beim Abrufen einer Resource auf dem entfernten Server. Dies könnte mit einem Zertifikatsfehler zusammenhängen.",
    "Error requesting resource on remote server" : "Fehler beim Abruf einer Resource auf dem entfernten Server",
    "%s has published the calendar \"%s\"" : "%s hat den Kalender \"%s\" veröffentlicht",
    "Individual" : "Einzelperson",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Raum",
    "Unknown" : "Unbekannt",
    "Required" : "Erforderlich",
    "Optional" : "Optional",
    "Does not attend" : "Nimmt nicht teil",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du bist in einer unbekannten Zeitzone ({tz}), Verwendung von UTC als Ersatz",
    "Please create a calendar first." : "Bitte erstelle zuerst einen Kalender.",
    "New event" : "Neues Ereignis",
    "CalDAV address for clients" : "CalDAV-Adresse für Clients",
    "Error saving WebCal-calendar" : "Fehler beim Speichern des WebCal-Kalenders",
    "WebDAV address for subscriptions" : "WebDAV-Adresse für Abonnements",
    "EMail has been sent." : "E-Mail wurde versendet.",
    "There was an issue while sending your EMail." : "Es ist ein Fehler beim Versenden der E-Mail aufgetreten.",
    "group" : "Gruppe",
    "Details" : "Details",
    "Attendees" : "Teilnehmer",
    "Reminders" : "Erinnerungen",
    "Repeating" : "Wiederholend",
    "When shared show full event" : "Wenn geteilt, ganzes Ereignis anzeigen",
    "When shared show only busy" : "Wenn geteilt, nur den Status beschäftigt anzeigen",
    "When shared hide this event" : "Wenn geteilt, Ereignis verstecken",
    "Confirmed" : "Bestätigt",
    "Tentative" : "Vorläufig",
    "Cancelled" : "Abgesagt",
    "Please add a title!" : "Bitte einen Titel hinzufügen!",
    "Please select a calendar!" : "Bitte einen Kalender auswählen!",
    "Global" : "Global",
    "None" : "Keine",
    "Every day" : "jeden Tag",
    "Every week" : "jede Woche",
    "Every month" : "jeden Monat",
    "Every year" : "jedes Jahr",
    "never" : "niemals",
    "after" : "nach",
    "How about getting started by importing some calendars?" : "Wie wäre es, wenn du damit beginnen würdest einige Kalender zu importieren?",
    "At time of event" : "Zum Zeitpunkt des Ereignisses",
    "5 minutes before" : "5 Minuten vorher",
    "10 minutes before" : "10 Minuten vorher",
    "15 minutes before" : "15 Minuten vorher",
    "30 minutes before" : "30 Minuten vorher",
    "1 hour before" : "1 Stunde vorher",
    "2 hours before" : "2 Stunden vorher",
    "Custom" : "benutzerdefiniert",
    "Audio" : "Audio",
    "E Mail" : "E-Mail",
    "Pop up" : "Pop-up",
    "sec" : "s",
    "min" : "min",
    "hours" : "Stunden",
    "days" : "Tagen",
    "week" : "Woche",
    "before" : "vorher",
    "start" : "Start",
    "end" : "Ende",
    "Editing reminders of unknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt.",
    "Week {number} of {year}" : "Woche {number} von {year}",
    "Successfully imported" : "Erfolgreich importiert",
    "Partially imported, 1 failure" : "Teilweise importiert, 1 Fehler",
    "Partially imported, {n} failures" : "Teilweise importiert , {n} Fehler",
    "Audio alarm" : "Akustischer Alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} vor Beginn des Ereignisses",
    "{type} {time} before the event ends" : "{type} {time} vor Ende des Ereignisses",
    "{type} {time} after the event starts" : "{type} {time} nach Beginn des Ereignisses",
    "{type} {time} after the event ends" : "{type} {time} nach Ende des Ereignisses",
    "{type} at the event's start" : "{type} am Beginn des Ereignisses",
    "{type} at the event's end" : "{type} am Ende des Ereignisses",
    "{type} at {time}" : "{type} um {time}",
    "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
    "Please enter a valid WebCal-URL" : "Bitte eine gültige WebCal-Adresse angeben",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Schwerer Fehler im webcal-Proxy. Bitte kontaktiere deinen Administrator für weitere Informationen.",
    "Title of the Event" : "Titel des Ereignisses",
    "starts" : "Beginn",
    "ends" : "Ende",
    "All day Event" : "Ganztägiges Ereignis",
    "Delete" : "Löschen",
    "Cancel" : "Abbrechen",
    "More ..." : "Mehr …",
    "Create" : "Erstellen",
    "Update" : "Aktualisieren",
    "Close" : "Schließen",
    "Location" : "Ort",
    "Description" : "Beschreibung",
    "Event status" : "Ereignisstatus",
    "Visibility when sharing" : "Sichtbarkeit wenn geteilt",
    "Export" : "Exportieren",
    "%s has published the calendar %s" : "%s hat den Kalender %s veröffentlicht",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Wir wollten dich informieren, dass %s den Kalender {boldstart}%s{boldend} veröffentlicht hat.",
    "Click here to access it" : "Klicke hier, um darauf zuzugreifen",
    "Cheers!" : "Danke!",
    "We wanted to inform you that %s has published the calendar %s." : "Wir möchten Dich darüber informieren, dass %s den Kalender %s veröffentlicht hat.",
    "Click on the link below to access it" : "Klicke auf den Link unten, um darauf zuzugreifen",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Aufgrund eines Softwarefehlers ist der Kalender zur Zeit nicht in der Lage, die Asset-Pipeline-Funktion zu unterstützen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Bitte kontaktiere deinen Administrator und bitte ihn, die Konfigurationsoption \"asset-pipeline.enabled\" zu deaktivieren.",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "Today" : "Heute",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Einige Einträge in diesem Kalender sind fehlerhaft. Bitte überprüfe die JavaScript-Konsole für weitere Informationen.",
    "Share Calendar" : "Kalender teilen",
    "Shared" : "Geteilt",
    "More" : "Mehr",
    "Edit" : "Bearbeiten",
    "Link" : "Link",
    "WebCal URL" : "WebCal-Adresse",
    "Download" : "Herunterladen",
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "can edit" : "kann bearbeiten",
    "Share link" : "Link teilen",
    "Public access" : "Öffentlicher Zugriff",
    "Email link to person" : "Link per E-Mail verschicken",
    "Send" : "Senden",
    "New Calendar" : "Neuer Kalender",
    "Name" : "Name",
    "New Subscription" : "Neues Abonnement",
    "WebCal-URL" : "WebCal-Adresse",
    "Go back" : "Zurück",
    "Go forward" : "Weiter",
    "Edit event" : "Ereignis bearbeiten",
    "Delete Event" : "Ereignis löschen",
    "Save Event" : "Ereignis speichern",
    "Time" : "Zeit",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Wiederholen",
    "times every" : "mal pro",
    "Add" : "Hinzufügen",
    "E-Mail address of attendee" : "E-Mail-Adresse des Teilnehmers",
    "Please add your email address in the personal settings in order to add attendees." : "Bitte gib deine E-Mail-Adresse in den Persönlichen Einstellungen an, um Teilnehmer hinzuzufügen.",
    "from" : "von",
    "to" : "an",
    "This event's repeating rule is not supported yet." : "Die Wiederholungsregel dieses Ereignisses wird noch nicht unterstützt.",
    "Support for advanced rules will be added with subsequent updates." : "Unterstützung für fortgeschrittene Regeln wird mit späteren Aktualisierungen hinzugefügt werden.",
    "Reset repeating rule" : "Wiederholungsregel zurücksetzen",
    "Repeat every ..." : "Wiederholen alle …",
    "end repeat ..." : "Wiederholung beenden …",
    "times" : "mal",
    "Import Calendars" : "Kalender importieren",
    "Import canceled" : "Import abgebrochen",
    "Analyzing calendar" : "Analysiere Kalender",
    "The file contains objects incompatible with the selected calendar" : "Die Datei enthält Objekte, die nicht mit dem ausgewählten Kalender kompatibel sind",
    "New calendar" : "Neuer Kalender",
    "File is empty" : "Datei ist leer",
    "Import scheduled" : "Import geplant",
    "Settings" : "Einstellungen",
    "Publish URL" : "URL veröffentlichen",
    "Iframe to integrate" : "Iframe zum Einbinden",
    "Settings & import" : "Einstellungen & Import",
    "Skip simple event editor" : "Einfachen Ereignis-Editor überspringen",
    "Show week numbers" : "Kalenderwochen anzeigen",
    "Import calendar" : "Kalender importieren",
    "No Calendars selected for import" : "Keine Kalender für den Import ausgewählt",
    "Primary CalDAV address" : "Primäre CalDAV-Adresse",
    "iOS/OS X CalDAV address" : "iOS-/OS-X-CalDAV-Adresse"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/de.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar \"%s\"" : "%s hat den Kalender \"%s\" veröffentlicht",
    "Too many redirects. Aborting ..." : "Zu viele Umleitungen. Abbruch ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Der entfernte Server erlaubt keinen Zugriff auf den Kalender (HTTP {%s} error)",
    "Error connecting to remote server" : "Fehler bei der Verbindung zum entfernten Server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fehler beim Abrufen einer Resource auf dem entfernten Server. Dies könnte mit einem Zertifikatsfehler zusammenhängen.",
    "Error requesting resource on remote server" : "Fehler beim Abruf einer Resource auf dem entfernten Server",
    "Individual" : "Einzelperson",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Raum",
    "Unknown" : "Unbekannt",
    "Required" : "Erforderlich",
    "Optional" : "Optional",
    "Does not attend" : "Nimmt nicht teil",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du bist in einer unbekannten Zeitzone ({tz}), Verwendung von UTC als Ersatz",
    "Please create a calendar first." : "Bitte erstelle zuerst einen Kalender.",
    "New event" : "Neues Ereignis",
    "CalDAV address for clients" : "CalDAV-Adresse für Clients",
    "Error saving WebCal-calendar" : "Fehler beim Speichern des WebCal-Kalenders",
    "WebDAV address for subscriptions" : "WebDAV-Adresse für Abonnements",
    "EMail has been sent." : "E-Mail wurde versendet.",
    "There was an issue while sending your EMail." : "Es ist ein Fehler beim Versenden der E-Mail aufgetreten.",
    "group" : "Gruppe",
    "Details" : "Details",
    "Attendees" : "Teilnehmer",
    "Reminders" : "Erinnerungen",
    "Repeating" : "Wiederholend",
    "When shared show full event" : "Wenn geteilt, ganzes Ereignis anzeigen",
    "When shared show only busy" : "Wenn geteilt, nur den Status beschäftigt anzeigen",
    "When shared hide this event" : "Wenn geteilt, Ereignis verstecken",
    "Confirmed" : "Bestätigt",
    "Tentative" : "Vorläufig",
    "Cancelled" : "Abgesagt",
    "Please add a title!" : "Bitte einen Titel hinzufügen!",
    "Please select a calendar!" : "Bitte einen Kalender auswählen!",
    "Global" : "Global",
    "None" : "Keine",
    "Every day" : "jeden Tag",
    "Every week" : "jede Woche",
    "Every month" : "jeden Monat",
    "Every year" : "jedes Jahr",
    "never" : "niemals",
    "after" : "nach",
    "How about getting started by importing some calendars?" : "Wie wäre es, wenn du damit beginnen würdest einige Kalender zu importieren?",
    "At time of event" : "Zum Zeitpunkt des Ereignisses",
    "5 minutes before" : "5 Minuten vorher",
    "10 minutes before" : "10 Minuten vorher",
    "15 minutes before" : "15 Minuten vorher",
    "30 minutes before" : "30 Minuten vorher",
    "1 hour before" : "1 Stunde vorher",
    "2 hours before" : "2 Stunden vorher",
    "Custom" : "benutzerdefiniert",
    "Audio" : "Audio",
    "E Mail" : "E-Mail",
    "Pop up" : "Pop-up",
    "sec" : "s",
    "min" : "min",
    "hours" : "Stunden",
    "days" : "Tagen",
    "week" : "Woche",
    "before" : "vorher",
    "start" : "Start",
    "end" : "Ende",
    "Editing reminders of unknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt.",
    "Week {number} of {year}" : "Woche {number} von {year}",
    "Successfully imported" : "Erfolgreich importiert",
    "Partially imported, 1 failure" : "Teilweise importiert, 1 Fehler",
    "Partially imported, {n} failures" : "Teilweise importiert , {n} Fehler",
    "Audio alarm" : "Akustischer Alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} vor Beginn des Ereignisses",
    "{type} {time} before the event ends" : "{type} {time} vor Ende des Ereignisses",
    "{type} {time} after the event starts" : "{type} {time} nach Beginn des Ereignisses",
    "{type} {time} after the event ends" : "{type} {time} nach Ende des Ereignisses",
    "{type} at the event's start" : "{type} am Beginn des Ereignisses",
    "{type} at the event's end" : "{type} am Ende des Ereignisses",
    "{type} at {time}" : "{type} um {time}",
    "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
    "Please enter a valid WebCal-URL" : "Bitte eine gültige WebCal-Adresse angeben",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Schwerer Fehler im webcal-Proxy. Bitte kontaktiere deinen Administrator für weitere Informationen.",
    "Title of the Event" : "Titel des Ereignisses",
    "starts" : "Beginn",
    "ends" : "Ende",
    "All day Event" : "Ganztägiges Ereignis",
    "Delete" : "Löschen",
    "Cancel" : "Abbrechen",
    "More ..." : "Mehr …",
    "Create" : "Erstellen",
    "Update" : "Aktualisieren",
    "Close" : "Schließen",
    "Location" : "Ort",
    "Description" : "Beschreibung",
    "Event status" : "Ereignisstatus",
    "Visibility when sharing" : "Sichtbarkeit wenn geteilt",
    "Export" : "Exportieren",
    "%s has published the calendar %s" : "%s hat den Kalender %s veröffentlicht",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Wir wollten dich informieren, dass %s den Kalender {boldstart}%s{boldend} veröffentlicht hat.",
    "Click here to access it" : "Klicke hier, um darauf zuzugreifen",
    "Cheers!" : "Danke!",
    "We wanted to inform you that %s has published the calendar %s." : "Wir möchten Dich darüber informieren, dass %s den Kalender %s veröffentlicht hat.",
    "Click on the link below to access it" : "Klicke auf den Link unten, um darauf zuzugreifen",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Aufgrund eines Softwarefehlers ist der Kalender zur Zeit nicht in der Lage, die Asset-Pipeline-Funktion zu unterstützen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Bitte kontaktiere deinen Administrator und bitte ihn, die Konfigurationsoption \"asset-pipeline.enabled\" zu deaktivieren.",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "Today" : "Heute",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Einige Einträge in diesem Kalender sind fehlerhaft. Bitte überprüfe die JavaScript-Konsole für weitere Informationen.",
    "Share Calendar" : "Kalender teilen",
    "Shared" : "Geteilt",
    "More" : "Mehr",
    "Edit" : "Bearbeiten",
    "Link" : "Link",
    "iCal link" : "iCal Link",
    "Download" : "Herunterladen",
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "can edit" : "kann bearbeiten",
    "Share link" : "Link teilen",
    "Public access" : "Öffentlicher Zugriff",
    "Email link to person" : "Link per E-Mail verschicken",
    "Send" : "Senden",
    "New Calendar" : "Neuer Kalender",
    "Name" : "Name",
    "New Subscription" : "Neues Abonnement",
    "Go back" : "Zurück",
    "Go forward" : "Weiter",
    "Edit event" : "Ereignis bearbeiten",
    "Delete Event" : "Ereignis löschen",
    "Save Event" : "Ereignis speichern",
    "Time" : "Zeit",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Wiederholen",
    "times every" : "mal pro",
    "Add" : "Hinzufügen",
    "E-Mail address of attendee" : "E-Mail-Adresse des Teilnehmers",
    "Please add your email address in the personal settings in order to add attendees." : "Bitte gib deine E-Mail-Adresse in den Persönlichen Einstellungen an, um Teilnehmer hinzuzufügen.",
    "from" : "von",
    "to" : "an",
    "This event's repeating rule is not supported yet." : "Die Wiederholungsregel dieses Ereignisses wird noch nicht unterstützt.",
    "Support for advanced rules will be added with subsequent updates." : "Unterstützung für fortgeschrittene Regeln wird mit späteren Aktualisierungen hinzugefügt werden.",
    "Reset repeating rule" : "Wiederholungsregel zurücksetzen",
    "Repeat every ..." : "Wiederholen alle …",
    "end repeat ..." : "Wiederholung beenden …",
    "times" : "mal",
    "Import Calendars" : "Kalender importieren",
    "Import canceled" : "Import abgebrochen",
    "Analyzing calendar" : "Analysiere Kalender",
    "The file contains objects incompatible with the selected calendar" : "Die Datei enthält Objekte, die nicht mit dem ausgewählten Kalender kompatibel sind",
    "New calendar" : "Neuer Kalender",
    "File is empty" : "Datei ist leer",
    "Import scheduled" : "Import geplant",
    "Subscribe & embed" : "Abonnieren & Einbetten",
    "Publish URL" : "URL veröffentlichen",
    "Iframe to integrate" : "Iframe zum Einbinden",
    "Settings & import" : "Einstellungen & Import",
    "Skip simple event editor" : "Einfachen Ereignis-Editor überspringen",
    "Show week numbers" : "Kalenderwochen anzeigen",
    "Import calendar" : "Kalender importieren",
    "No Calendars selected for import" : "Keine Kalender für den Import ausgewählt",
    "Primary CalDAV address" : "Primäre CalDAV-Adresse",
    "iOS/OS X CalDAV address" : "iOS-/OS-X-CalDAV-Adresse"
},
"nplurals=2; plural=(n != 1);");
